module AFrame.Components.Controls.Vive exposing

    ( hand, model
    , buttonColor, buttonHighlightColor
    , orientationOffset
    )

{-| # Vive Controls

# Basic

@docs hand,  model

# Buttons colors

@docs buttonColor, buttonHighlightColor

# Orientation

@docs orientationOffset

-}


import Color exposing (Color)

import AFrame.Variants.Hand exposing (Hand)
import AFrame.Variants.Hand as Hand exposing (toString)

import AFrame.Properties exposing (Property, property)
import AFrame.Util exposing (..)



{-| Set hand that will be tracked (i.e., `right`, `left`). -}
hand : Hand -> Property
hand = property "hand" << Hand.toString


{-| Button colors when not pressed.

Default : `#FAFAFA` (_off-white_)
-}
buttonColor : Color -> Property
buttonColor = property "buttonColor" << Color.toCssString


{-| Button colors when pressed and active.

Default : `#22D1EE` (_light blue_)
-}
buttonHighlightColor : Color -> Property
buttonHighlightColor = property "buttonHighlightColor" << Color.toCssString


{-| Whether the Vive controller model is loaded.

Default : `true`
-}
model : Bool -> Property
model = property "model" << boolToString


{-| Offset to apply to model orientation.

Default: `x: 0, y: 0, z: 0`
-}
orientationOffset : Float -> Float -> Float -> Property
orientationOffset x y z = property "orientationOffset" <| vec3ToString x y z
